---
title: '[릴리즈노트] 2024-04-12 업데이트'
category: 업데이트
tags:
  - API / SDK
  - 업데이트
searchTags:
  - 한국결제네트웍스
  - KPN
  - V2 신모듈
  - 업데이트
  - 릴리즈노트
datetime: 2024-04-16T07:55:25.448Z
---

<Callout title="2024년 04월 12일 API/SDK 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

✔️ 포트원 V2 신모듈에서 한국결제네트웍스(KPN) 결제를 지원합니다.

이제 포트원 V2를 통해 한국결제네트웍스 일반결제 및 정기결제가 가능합니다. 이번 업데이트를 통해 다양한 결제수단을 제공하며, 일부 간편결제에 대해 허브형과 다이렉트 호출을 지원합니다.

한국결제네트웍스에서 지원하는 결제수단은 아래와 같습니다.

- 카드
- 실시간 계좌이체
- 가상계좌 (회전식)
- 휴대폰 소액결제
- 간편결제 (허브형/다이렉트)
  - 카카오페이
  - 네이버페이 (다이렉트 호출 불가)
  - 페이코
  - 삼성페이
  - 토스페이

이 외에도 SDK/API 빌링키 발급, 에스크로, API 가상계좌 발급 및 말소, 면세 금액 지정, 상점분담무이자 등의 기능을 지원합니다.

한국결제네트웍스 연동에 대해 자세히 알고 싶다면 [한국결제네트웍스 연동가이드↗](https://developers.portone.io/opi/ko/integration/pg/v2/kpn?v=v2)에서 확인하실 수 있습니다.

[\[API/SDK 릴리즈노트\] 2024-04-12 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-04-12?v=v2)
